]> sigrok.org Git - libsigrok.git/blobdiff - sigrok.h
Mark some private stuff 'static'.
[libsigrok.git] / sigrok.h
index 59ab45b50714b0148bc0e0de7d525f7b331b5c02..e2bbecc59a24281af38471a7ce5ec7701dc5570d 100644 (file)
--- a/sigrok.h
+++ b/sigrok.h
@@ -25,7 +25,9 @@
 #include <stdint.h>
 #include <inttypes.h>
 #include <glib.h>
+#ifdef HAVE_LIBUSB_1_0
 #include <libusb.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -173,7 +175,7 @@ struct analyzer {
 /* Size of a chunk in units */
 #define DATASTORE_CHUNKSIZE 512000
 
-struct datastore {
+struct sr_datastore {
        /* Size in bytes of the number of units stored in this datastore */
        int ds_unitsize;
        unsigned int num_units; /* TODO: uint64_t */
@@ -191,10 +193,10 @@ struct sr_device {
        struct sr_device_plugin *plugin;
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
/* List of struct probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
-       struct datastore *datastore;
+       struct sr_datastore *datastore;
 };
 
 enum {
@@ -202,7 +204,7 @@ enum {
        SR_PROBE_TYPE_ANALOG,
 };
 
-struct probe {
+struct sr_probe {
        int index;
        int type;
        gboolean enabled;
@@ -235,7 +237,7 @@ enum {
        SR_HWCAP_CONTINUOUS,
 };
 
-struct hwcap_option {
+struct sr_hwcap_option {
        int capability;
        int type;
        char *description;
@@ -262,11 +264,13 @@ enum {
        SR_SERIAL_INSTANCE,
 };
 
+#ifdef HAVE_LIBUSB_1_0
 struct sr_usb_device_instance {
        uint8_t bus;
        uint8_t address;
        struct libusb_device_handle *devhdl;
 };
+#endif
 
 struct sr_serial_device_instance {
        char *port;
@@ -295,7 +299,7 @@ enum {
        SR_DI_INSTANCE,
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
/* Samplerates supported by this device, (struct samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */
        SR_DI_TRIGGER_TYPES,
@@ -310,7 +314,7 @@ enum {
  * granularity, or is limited to a set of defined samplerates. Use either
  * step or list, but not both.
  */
-struct samplerates {
+struct sr_samplerates {
        uint64_t low;
        uint64_t high;
        uint64_t step;
@@ -336,7 +340,7 @@ struct sr_device_plugin {
        void (*stop_acquisition) (int device_index, gpointer session_device_id);
 };
 
-struct session {
+struct sr_session {
        /* List of struct sr_device* */
        GSList *devices;
        /* List of struct analyzer* */
@@ -191,10 +193,10 @@ struct sr_device {
        /* A plugin may handle multiple devices of the same type */
        int plugin_index;
-       /* List of struct probe* */
+       /* List of struct sr_probe* */
        GSList *probes;
        /* Data acquired by this device, if any */
@@ -295,7 +299,7 @@ enum {
        /* The number of probes connected to this device */
        SR_DI_NUM_PROBES,
-       /* Samplerates supported by this device, (struct samplerates) */
+       /* Samplerates supported by this device, (struct sr_samplerates) */
        SR_DI_SAMPLERATES,
        /* Types of trigger supported, out of "01crf" (char *) */